# PulpFileClient::RepositoriesFileVersionsApi

All URIs are relative to *http://pulp*

Method | HTTP request | Description
------------- | ------------- | -------------
[**delete**](RepositoriesFileVersionsApi.md#delete) | **DELETE** {file_file_repository_version_href} | Delete a repository version
[**list**](RepositoriesFileVersionsApi.md#list) | **GET** {file_file_repository_href}versions/ | List repository versions
[**read**](RepositoriesFileVersionsApi.md#read) | **GET** {file_file_repository_version_href} | Inspect a repository version
[**repair**](RepositoriesFileVersionsApi.md#repair) | **POST** {file_file_repository_version_href}repair/ | 



## delete

> AsyncOperationResponse delete(file_file_repository_version_href)

Delete a repository version

Trigger an asynchronous task to delete a repository version.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::RepositoriesFileVersionsApi.new
file_file_repository_version_href = 'file_file_repository_version_href_example' # String | 

begin
  #Delete a repository version
  result = api_instance.delete(file_file_repository_version_href)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling RepositoriesFileVersionsApi->delete: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_repository_version_href** | **String**|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## list

> PaginatedRepositoryVersionResponseList list(file_file_repository_href, opts)

List repository versions

 FileRepositoryVersion represents a single file repository version.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::RepositoriesFileVersionsApi.new
file_file_repository_href = 'file_file_repository_href_example' # String | 
opts = {
  content: 'content_example', # String | Content Unit referenced by HREF
  content__in: 'content__in_example', # String | Content Unit referenced by HREF
  limit: 56, # Integer | Number of results to return per page.
  number: 56, # Integer | Filter results where number matches value
  number__gt: 56, # Integer | Filter results where number is greater than value
  number__gte: 56, # Integer | Filter results where number is greater than or equal to value
  number__lt: 56, # Integer | Filter results where number is less than value
  number__lte: 56, # Integer | Filter results where number is less than or equal to value
  number__range: [56], # Array<Integer> | Filter results where number is between two comma separated values
  offset: 56, # Integer | The initial index from which to return the results.
  ordering: ['ordering_example'], # Array<String> | Ordering  * `pulp_id` - Pulp id * `-pulp_id` - Pulp id (descending) * `pulp_created` - Pulp created * `-pulp_created` - Pulp created (descending) * `pulp_last_updated` - Pulp last updated * `-pulp_last_updated` - Pulp last updated (descending) * `number` - Number * `-number` - Number (descending) * `complete` - Complete * `-complete` - Complete (descending) * `info` - Info * `-info` - Info (descending) * `pk` - Pk * `-pk` - Pk (descending)
  pulp_created: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created matches value
  pulp_created__gt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is greater than value
  pulp_created__gte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is greater than or equal to value
  pulp_created__lt: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is less than value
  pulp_created__lte: DateTime.parse('2013-10-20T19:20:30+01:00'), # DateTime | Filter results where pulp_created is less than or equal to value
  pulp_created__range: [DateTime.parse('2013-10-20T19:20:30+01:00')], # Array<DateTime> | Filter results where pulp_created is between two comma separated values
  pulp_href__in: ['pulp_href__in_example'], # Array<String> | Multiple values may be separated by commas.
  q: 'q_example', # String | 
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #List repository versions
  result = api_instance.list(file_file_repository_href, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling RepositoriesFileVersionsApi->list: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_repository_href** | **String**|  | 
 **content** | **String**| Content Unit referenced by HREF | [optional] 
 **content__in** | **String**| Content Unit referenced by HREF | [optional] 
 **limit** | **Integer**| Number of results to return per page. | [optional] 
 **number** | **Integer**| Filter results where number matches value | [optional] 
 **number__gt** | **Integer**| Filter results where number is greater than value | [optional] 
 **number__gte** | **Integer**| Filter results where number is greater than or equal to value | [optional] 
 **number__lt** | **Integer**| Filter results where number is less than value | [optional] 
 **number__lte** | **Integer**| Filter results where number is less than or equal to value | [optional] 
 **number__range** | [**Array&lt;Integer&gt;**](Integer.md)| Filter results where number is between two comma separated values | [optional] 
 **offset** | **Integer**| The initial index from which to return the results. | [optional] 
 **ordering** | [**Array&lt;String&gt;**](String.md)| Ordering  * &#x60;pulp_id&#x60; - Pulp id * &#x60;-pulp_id&#x60; - Pulp id (descending) * &#x60;pulp_created&#x60; - Pulp created * &#x60;-pulp_created&#x60; - Pulp created (descending) * &#x60;pulp_last_updated&#x60; - Pulp last updated * &#x60;-pulp_last_updated&#x60; - Pulp last updated (descending) * &#x60;number&#x60; - Number * &#x60;-number&#x60; - Number (descending) * &#x60;complete&#x60; - Complete * &#x60;-complete&#x60; - Complete (descending) * &#x60;info&#x60; - Info * &#x60;-info&#x60; - Info (descending) * &#x60;pk&#x60; - Pk * &#x60;-pk&#x60; - Pk (descending) | [optional] 
 **pulp_created** | **DateTime**| Filter results where pulp_created matches value | [optional] 
 **pulp_created__gt** | **DateTime**| Filter results where pulp_created is greater than value | [optional] 
 **pulp_created__gte** | **DateTime**| Filter results where pulp_created is greater than or equal to value | [optional] 
 **pulp_created__lt** | **DateTime**| Filter results where pulp_created is less than value | [optional] 
 **pulp_created__lte** | **DateTime**| Filter results where pulp_created is less than or equal to value | [optional] 
 **pulp_created__range** | [**Array&lt;DateTime&gt;**](DateTime.md)| Filter results where pulp_created is between two comma separated values | [optional] 
 **pulp_href__in** | [**Array&lt;String&gt;**](String.md)| Multiple values may be separated by commas. | [optional] 
 **q** | **String**|  | [optional] 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**PaginatedRepositoryVersionResponseList**](PaginatedRepositoryVersionResponseList.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## read

> RepositoryVersionResponse read(file_file_repository_version_href, opts)

Inspect a repository version

 FileRepositoryVersion represents a single file repository version.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::RepositoriesFileVersionsApi.new
file_file_repository_version_href = 'file_file_repository_version_href_example' # String | 
opts = {
  fields: ['fields_example'], # Array<String> | A list of fields to include in the response.
  exclude_fields: ['exclude_fields_example'] # Array<String> | A list of fields to exclude from the response.
}

begin
  #Inspect a repository version
  result = api_instance.read(file_file_repository_version_href, opts)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling RepositoriesFileVersionsApi->read: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_repository_version_href** | **String**|  | 
 **fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to include in the response. | [optional] 
 **exclude_fields** | [**Array&lt;String&gt;**](String.md)| A list of fields to exclude from the response. | [optional] 

### Return type

[**RepositoryVersionResponse**](RepositoryVersionResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## repair

> AsyncOperationResponse repair(file_file_repository_version_href, repair)



Trigger an asynchronous task to repair a repository version.

### Example

```ruby
# load the gem
require 'pulp_file_client'
# setup authorization
PulpFileClient.configure do |config|
  # Configure HTTP basic authorization: basicAuth
  config.username = 'YOUR USERNAME'
  config.password = 'YOUR PASSWORD'
end

api_instance = PulpFileClient::RepositoriesFileVersionsApi.new
file_file_repository_version_href = 'file_file_repository_version_href_example' # String | 
repair = PulpFileClient::Repair.new # Repair | 

begin
  result = api_instance.repair(file_file_repository_version_href, repair)
  p result
rescue PulpFileClient::ApiError => e
  puts "Exception when calling RepositoriesFileVersionsApi->repair: #{e}"
end
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **file_file_repository_version_href** | **String**|  | 
 **repair** | [**Repair**](Repair.md)|  | 

### Return type

[**AsyncOperationResponse**](AsyncOperationResponse.md)

### Authorization

[basicAuth](../README.md#basicAuth)

### HTTP request headers

- **Content-Type**: application/json, application/x-www-form-urlencoded, multipart/form-data
- **Accept**: application/json

